pub struct FileDecompressor {
pub lines_consumed: usize,
/* private fields */
}Expand description
State for incremental zstd decompression and line extraction from a single file.
Fields
lines_consumed: usizeGlobal line index up to which lines have been consumed or skipped. This is the value that should be used for checkpointing. Equals skip_before + number of lines actually returned to caller.
Implementations
Sourceimpl FileDecompressor
impl FileDecompressor
Sourcepub fn open(path: &Path) -> Result<Self>
pub fn open(path: &Path) -> Result<Self>
Open a file and prepare for incremental zstd decompression.
Sourcepub fn next_line(
&mut self,
skip_before: usize,
) -> Result<Option<DecompressedLine>>
pub fn next_line( &mut self, skip_before: usize, ) -> Result<Option<DecompressedLine>>
Get the next line from this file.
skip_before: lines with index < skip_before are discarded.
Returns:
Ok(Some(line))— a complete line was extracted.Ok(None)— no more data available right now. The caller should check if the file is done or retry later.
Sourcepub fn reset_eof(&mut self)
pub fn reset_eof(&mut self)
Reset the EOF flag so we can try reading more data (useful when tailing a file that is still being written to).
Sourcepub fn has_partial_data(&self) -> bool
pub fn has_partial_data(&self) -> bool
Returns true if there is partial (incomplete line) data remaining in the output buffer.